@@ -107,6 +107,7 @@ tools_init_options(struct tools_options *options)
 	options->left_handed = -1;
 	options->middlebutton = -1;
 	options->dwt = -1;
+	options->dwtp = -1;
 	options->click_method = -1;
 	options->scroll_method = -1;
 	options->scroll_button = -1;
@@ -175,6 +176,12 @@ tools_parse_option(int option,
 	case OPT_DWT_DISABLE:
 		options->dwt = LIBINPUT_CONFIG_DWT_DISABLED;
 		break;
+	case OPT_DWTP_ENABLE:
+		options->dwtp = LIBINPUT_CONFIG_DWTP_ENABLED;
+		break;
+	case OPT_DWTP_DISABLE:
+		options->dwtp = LIBINPUT_CONFIG_DWTP_DISABLED;
+		break;
 	case OPT_CLICK_METHOD:
 		if (!optarg)
 			return 1;
